@@ -53,7 +53,7 @@ rcube_webmail.prototype.sieverules_mouse_up = function(e) {
 		var _src = rcmail.sieverules_list.get_single_selection();
 
 		if (rcmail.env.sieverules_last_target == 'end') {
-			var _dst = rcmail.sieverules_list.rows.length;
+			var _dst = rcmail.sieverules_list.rowcount;
 			$(rcmail.gui_objects.sieverules_list).children('tbody').children('tr:last').removeClass('droptargetend');
 		}
 		else {
@@ -89,7 +89,7 @@ rcube_webmail.prototype.sieverules_drag_start = function(list) {
 
 		rows = rcmail.sieverules_list.rows;
 		rcmail.env.sieverules_coords = new Array();
-		for (var i = 0; i < rows.length; i++) {
+		for (var i = 0; i < rcmail.sieverules_list.rowcount; i++) {
 			pos = $('#' + rows[i].id).offset();
 			rcmail.env.sieverules_coords[rows[i].id] = { x1:pos.left, y1:pos.top, x2:pos.left + $('#' + rows[i].id).width(), y2:pos.top + $('#' + rows[i].id).height(), on:0 };
 		}
@@ -186,7 +186,7 @@ rcube_webmail.prototype.sieverules_ready = function(id) {
 	return true;
 }
 
-rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2, param3, param4) {
+rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2, param3) {
 	var sid = rcmail.sieverules_list.get_single_selection();
 	var selection;
 	var rows = rcmail.sieverules_list.rows;
@@ -196,7 +196,7 @@ rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2
 		case 'add-first':
 			rcmail.sieverules_list.clear();
 		case 'add':
-			if (rows.length == 1 && rows[0].obj.cells[0].innerHTML == rcmail.gettext('loading',''))
+			if (rcmail.sieverules_list.rowcount == 1 && rows[0].obj.cells[0].innerHTML == rcmail.gettext('loading',''))
 				rcmail.sieverules_list.remove_row(0);
 
 			var newrow = document.createElement('tr');
@@ -217,9 +217,8 @@ rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2
 				cell.className = 'control';
 
 				param3 = param3.replace(/\\'/g, '\'');
-				param4 = param4.replace(/\\'/g, '\'');
 
-				cell.innerHTML = param3 + param4;
+				cell.innerHTML = param3;
 				newrow.appendChild(cell);
 			}
 
@@ -245,7 +244,7 @@ rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2
 			break;
 		case 'move':
 			// create array of rules
-			for (var i = 0; i < rows.length; i++) {
+			for (var i = 0; i < rcmail.sieverules_list.rowcount; i++) {
 				rules[i] = rows[i].obj.cells[0].innerHTML;
 
 				if (sid == i) selection = rules[i];
@@ -260,7 +259,7 @@ rcube_webmail.prototype.sieverules_update_list = function(action, param1, param2
 				rules.splice(parseInt(param1) + 1, 1);
 
 			// update table
-			for (var i = 0; i < rows.length; i++) {
+			for (var i = 0; i < rcmail.sieverules_list.rowcount; i++) {
 				rows[i].obj.cells[0].innerHTML = rules[i];
 
 				if (rules[i] == selection) sid = i;
@@ -581,7 +580,7 @@ rcube_webmail.prototype.sieverules_action_select = function(sel) {
 	document.getElementsByName('_redirect[]')[idx].style.display = 'none';
 	document.getElementsByName('_reject[]')[idx].style.display = 'none';
 	document.getElementsByName('_imapflags[]')[idx].style.display = 'none';
-	document.getElementsByName('_day[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
+	document.getElementsByName('_period[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
 	document.getElementsByName('_nmethod[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
 	document.getElementsByName('_eheadname[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = 'none';
 
@@ -590,7 +589,7 @@ rcube_webmail.prototype.sieverules_action_select = function(sel) {
 	else if (obj.value == 'reject' || obj.value == 'ereject')
 		document.getElementsByName('_reject[]')[idx].style.display = '';
 	else if (obj.value == 'vacation') {
-		document.getElementsByName('_day[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = '';
+		document.getElementsByName('_period[]')[idx].parentNode.parentNode.parentNode.parentNode.style.display = '';
 
 		if (rcmail.env.sieverules_htmleditor == 1) {
 			rowid = document.getElementsByName('_msg[]')[idx].id.replace('rcmfd_sievevacmag_', '');
@@ -692,6 +691,11 @@ rcube_webmail.prototype.sieverules_notify_impt = function(sel, id) {
 	obj.value = sel.value == 'none' ? '' : sel.value;
 }
 
+rcube_webmail.prototype.sieverules_period_type = function(sel, id) {
+	var obj = rcube_find_object('rcmfd_sievevacperiodtype_' + id);
+	obj.value = sel.value;
+}
+
 rcmail.sieverules_help = function(sel, row) {
 	var obj = sel.parentNode.parentNode.parentNode.parentNode;
 	var help_row = obj.tBodies[0].rows[row];
@@ -839,16 +843,6 @@ rcube_webmail.prototype.sieverules_toggle_eheadlast = function(obj) {
 $(document).ready(function() {
 	if (window.rcmail) {
 		rcmail.addEventListener('init', function(evt) {
-			if (rcmail.env.action == 'plugin.sieverules.add' || rcmail.env.action == 'plugin.sieverules.edit' || rcmail.env.action == 'plugin.sieverules.setup' || rcmail.env.action == 'plugin.sieverules.advanced')
-				var tab = $('<span>').attr('id', 'settingstabpluginsieverules').addClass('tablink selected');
-			else
-				var tab = $('<span>').attr('id', 'settingstabpluginsieverules').addClass('tablink');
-
-			var button = $('<a>').attr('href', rcmail.env.comm_path+'&_action=plugin.sieverules').attr('title', rcmail.gettext('managefilters', 'sieverules')).html(rcmail.gettext('filters','sieverules')).appendTo(tab);
-
-			// add button and register command
-			rcmail.add_element(tab, 'tabs');
-
 			if ((rcmail.env.action == 'plugin.sieverules' || rcmail.env.action == 'plugin.sieverules.advanced') && !rcmail.env.sieveruleserror) {
 				if (rcmail.gui_objects.sieverules_list) {
 					rcmail.sieverules_list = new rcube_list_widget(rcmail.gui_objects.sieverules_list, {multiselect:false, draggable:true, keyboard:true});
@@ -865,7 +859,7 @@ $(document).ready(function() {
 					rcmail.sieverules_list.init();
 					rcmail.sieverules_list.focus();
 
-					if (rcmail.env.iid && rcmail.env.iid < rcmail.sieverules_list.rows.length && !rcmail.env.eid)
+					if (rcmail.env.iid && rcmail.env.iid < rcmail.sieverules_list.rowcount && !rcmail.env.eid)
 						rcmail.sieverules_list.select_row(rcmail.env.iid, false, false);
 				}
 
@@ -892,7 +886,7 @@ $(document).ready(function() {
 					rcmail.register_command('plugin.sieverules.move', function(props, obj) {
 						var args = (props.source) ? props : { source:obj.parentNode.parentNode.rowIndex - 1, dest:props };
 
-						if (args.dest > -1 && args.dest <= rcmail.sieverules_list.rows.length) {
+						if (args.dest > -1 && args.dest <= rcmail.sieverules_list.rowcount) {
 							var lock = rcmail.set_busy(true, 'sieverules.movingfilter');
 							rcmail.http_request('plugin.sieverules.move', '_src=' + args.source + '&_dst=' + args.dest, lock);
 						}
@@ -1138,12 +1132,16 @@ $(document).ready(function() {
 				}, false);
 
 				rcmail.register_command('plugin.sieverules.save', function() {
-					var rows;
+					var rows, rowcount;
 
-					if (rcmail.env.framed)
+					if (rcmail.env.framed) {
 						rows = parent.rcmail.sieverules_list.rows;
-					else
+						rowcount = parent.rcmail.sieverules_list.rowcount;
+					}
+					else {
 						rows = rcmail.sieverules_list.rows;
+						rowcount = rcmail.sieverules_list.rowcount;
+					}
 
 					var input_name = rcube_find_object('_name');
 					var rule_join = document.getElementsByName('_join');
@@ -1162,7 +1160,7 @@ $(document).ready(function() {
 					var rejects = document.getElementsByName('_reject[]');
 					var senders = document.getElementsByName('_vacfrom[]');
 					var aliases = document.getElementsByName('_vacto[]');
-					var days = document.getElementsByName('_day[]');
+					var periods = document.getElementsByName('_period[]');
 					var subjects = document.getElementsByName('_subject[]');
 					var msgs = document.getElementsByName('_msg[]');
 					var nmethods = document.getElementsByName('_nmethod[]');
@@ -1181,7 +1179,7 @@ $(document).ready(function() {
 						return false;
 					}
 
-					for (var i = 0; i < rows.length; i++) {
+					for (var i = 0; i < rowcount; i++) {
 						if (input_name.value == rows[i].obj.cells[0].innerHTML && i != rcmail.env.iid) {
 							alert(rcmail.gettext('ruleexists','sieverules'));
 							input_name.focus();
@@ -1297,15 +1295,15 @@ $(document).ready(function() {
 								return false;
 							}
 
-							if (days[i].value == '') {
-								alert(rcmail.gettext('vacnodays','sieverules'));
-								days[i].focus();
-								return false;
-							}
+							//if (periods[i].value == '') {
+							//	alert(rcmail.gettext('vacnoperiod','sieverules'));
+							//	periods[i].focus();
+							//	return false;
+							//}
 
-							if (!size_test.test(days[i].value) || days[i].value < 1) {
-								alert(rcmail.gettext('vacdayswrongformat','sieverules'));
-								days[i].focus();
+							if (periods[i].value != '' && (!size_test.test(periods[i].value) || periods[i].value < 1)) {
+								alert(rcmail.gettext('vacperiodwrongformat','sieverules'));
+								periods[i].focus();
 								return false;
 							}
 
@@ -1362,6 +1360,67 @@ $(document).ready(function() {
 					for (var i = 0; i < document.getElementsByName('_comparator[]').length; i++)
 						document.getElementsByName('_comparator[]')[i].disabled = false;
 
+					// remove "template" rows
+					var rulesTable = rcube_find_object('rules-table').tBodies[0];
+					rulesTable.deleteRow(2);
+					rulesTable.deleteRow(1);
+					rulesTable.deleteRow(0);
+
+					var actsTable = rcube_find_object('actions-table').tBodies[0];
+					actsTable.deleteRow(0);
+
+					// disable unused rule fields
+					var fields = ['_bodypart', '_size_operator', '_date_operator', '_spamtest_operator', '_units', '_body_contentpart', '_comparator', '_advoperator', '_advtarget', '_datepart', '_weekday', '_advweekday'];
+					for (var i = 0; i < fields.length; i++) {
+						if ($('form.propform select[name="'+ fields[i] +'[]"]:visible').length == 0 && $('form.propform input[name="'+ fields[i] +'[]"]:visible').length == 0) {
+							$('form.propform select[name="'+ fields[i] +'[]"]').attr('disabled', 'disabled');
+							$('form.propform input[name="'+ fields[i] +'[]"]').attr('disabled', 'disabled');
+						}
+					}
+
+					// disable unused action fields
+					var actions = ['_folder', '_redirect', '_reject', '_subject', '_imapflags', '_nmethod', '_eheadname'];
+					for (var i = 0; i < actions.length; i++) {
+						if ($('form.propform select[name="'+ actions[i] +'[]"]:visible').length == 0 && $('form.propform input[name="'+ actions[i] +'[]"]:visible').length == 0 && $('form.propform textarea[name="'+ actions[i] +'[]"]:visible').length == 0) {
+							switch(actions[i]) {
+								case '_folder':
+									$('form.propform select[name="_folder[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_customfolder[]"]').attr('disabled', 'disabled');
+									break;
+								case '_subject':
+									$('form.propform select[name="_vacfrom[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_vacfrom[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_vacto[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_period[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_periodtype[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_handle[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_subject[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_orig_subject[]"]').attr('disabled', 'disabled');
+									$('form.propform textarea[name="_msg[]"]').attr('disabled', 'disabled');
+									$('form.propform textarea[name="_htmlmsg[]"]').attr('disabled', 'disabled');
+									$('form.propform select[name="_vaccharset[]"]').attr('disabled', 'disabled');
+									break;
+								case '_nmethod':
+									$('form.propform select[name="_nfrom[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_nimpt[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_nmethod[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_noption[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_nmsg[]"]').attr('disabled', 'disabled');
+									break;
+								case '_eheadname':
+									$('form.propform input[name="_eheadname[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="_eheadval[]"]').attr('disabled', 'disabled');
+									$('form.propform select[name="_eheadopp[]"]').attr('disabled', 'disabled');
+									$('form.propform select[name="_eheadindex[]"]').attr('disabled', 'disabled');
+									break;
+								default:
+									$('form.propform select[name="'+ actions[i] +'[]"]').attr('disabled', 'disabled');
+									$('form.propform input[name="'+ actions[i] +'[]"]').attr('disabled', 'disabled');
+									$('form.propform textarea[name="'+ actions[i] +'[]"]').attr('disabled', 'disabled');
+							}
+						}
+					}
+
 					rcmail.gui_objects.editform.submit();
 				}, true);
 
@@ -1372,13 +1431,13 @@ $(document).ready(function() {
 					if (!obj || !obj.options)
 						return false;
 
-					var sig, id;
+					var sig, sig_id;
 					var sig_separator = '-- ';
 
 					if (obj.options[0].value == 'auto' || obj.options[0].value == '')
-						id = obj.selectedIndex;
+						sig_id = obj.selectedIndex;
 					else
-						id = obj.selectedIndex + 1;
+						sig_id = obj.selectedIndex + 1;
 
 					if (is_html) {
 						var editor = tinyMCE.get("rcmfd_sievevacmag_" + id),
@@ -1398,14 +1457,14 @@ $(document).ready(function() {
 							body.appendChild(sigElem);
 						}
 
-						if (rcmail.env.signatures[id]) {
-							if (rcmail.env.signatures[id].is_html) {
-								sig = rcmail.env.signatures[id].text;
-								if (!rcmail.env.signatures[id].plain_text.match(/^--[ -]\r?\n/m))
+						if (rcmail.env.signatures[sig_id]) {
+							if (rcmail.env.signatures[sig_id].is_html) {
+								sig = rcmail.env.signatures[sig_id].text;
+								if (!rcmail.env.signatures[sig_id].plain_text.match(/^--[ -]\r?\n/m))
 									sig = sig_separator + '<br />' + sig;
 							}
 							else {
-								sig = rcmail.env.signatures[id].text;
+								sig = rcmail.env.signatures[sig_id].text;
 								if (!sig.match(/^--[ -]\r?\n/m))
 									sig = sig_separator + '\n' + sig;
 
@@ -1419,8 +1478,8 @@ $(document).ready(function() {
 						var input_message = $("#rcmfd_sievevacmag_" + id);
 						var message = input_message.val();
 
-						if (rcmail.env.signatures && rcmail.env.signatures[id]) {
-							sig = rcmail.env.signatures[id]['text'];
+						if (rcmail.env.signatures && rcmail.env.signatures[sig_id]) {
+							sig = rcmail.env.signatures[sig_id]['text'];
 							sig = sig.replace(/\r\n/g, '\n');
 
 							if (!sig.match(/^--[ -]\n/))
